AFRL/RDE labeling Object Info (sarpy.annotation.afrl_rde_elements.ObjectInfo)
=============================================================================

.. automodule:: sarpy.annotation.afrl_rde_elements.ObjectInfo
    :members:
    :show-inheritance:
    :inherited-members:
